<?php
namespace Setka\Editor\Service\AMP;

use Korobochkin\WPKit\Options\OptionInterface;
use Setka\Editor\Admin\Service\WPQueryFactory;
use Setka\Editor\Service\SetkaPostTypes;

class AMPStatus
{
    /**
     * @var OptionInterface[]
     */
    private $options = array();

    /**
     * @var \wpdb
     */
    private $wpdb;

    /**
     * @var array
     */
    private static $types = array(
        SetkaPostTypes::AMP_COMMON => 'common',
        SetkaPostTypes::AMP_THEME => 'theme',
        SetkaPostTypes::AMP_LAYOUT => 'layout',
        SetkaPostTypes::AMP_CONFIG => 'config',
    );

    const RESULT_UNKNOWN_FORMAT = 'Unknown result from $wpdb->query()';

    /**
     * AMPStatus constructor.
     *
     * @param OptionInterface[] $options
     * @param \wpdb $wpdb
     */
    public function __construct(array $options, \wpdb $wpdb)
    {
        $this->options = $options;
        $this->wpdb    = $wpdb;
    }

    /**
     * @return array List of option names and its values.
     */
    public function getCurrentSettings()
    {
        $options = array();
        foreach ($this->options as $option) {
            $options[$option->getName()] = $option->get();
        }
        return $options;
    }

    /**
     * @return array
     */
    public function getCSSList()
    {
        $query = WPQueryFactory::createAMPRelated();
        $items = array();

        while ($query->have_posts()) {
            $post = $query->next_post();

            $items[] = array(
                'ID' => $post->ID,
                'post_name' => $post->post_name,
                'post_status' => $post->post_status,
                'post_type' => $this->getCSSType($post),
            );
        }
        return $items;
    }

    /**
     * @param \WP_Post $post
     *
     * @return string
     */
    private function getCSSType(\WP_Post $post)
    {
        if (isset(self::$types[$post->post_type])) {
            return self::$types[$post->post_type];
        }
        return 'unknown';
    }

    /**
     * @param $human bool
     * @return array
     */
    public function getCSSCounters($human = true)
    {
        $counters = array();
        foreach (self::$types as $type => $humanReadable) {
            $counters[($human) ? $humanReadable : $type] = $this->getCounter($type);
        }
        return $counters;
    }

    /**
     * @param $type string
     *
     * @return \Exception|int
     */
    private function getCounter($type)
    {
        return $this->query(
            "SELECT
            COUNT(ID) AS counter
            FROM {$this->wpdb->posts}
            WHERE post_type = %s",
            $type
        );
    }

    /**
     * @param $query
     * @param $replace
     *
     * @return \Exception|int
     */
    private function query($query, $replace)
    {
        // phpcs:disable WordPress.DB.PreparedSQL.NotPrepared
        return $this->castQueryResult($this->wpdb->get_results($this->wpdb->prepare($query, $replace), ARRAY_A));
        // phpcs:enable
    }

    /**
     * @param $results
     *
     * @return \Exception|int
     */
    private function castQueryResult($results)
    {
        if (isset($results[0]['counter']) && is_numeric($results[0]['counter'])) {
            return (int) $results[0]['counter'];
        }
        return new \Exception(self::RESULT_UNKNOWN_FORMAT);
    }
}
